@@ -8,7 +8,7 @@ from gmat.process_plink.process_plink import impute_geno
 from scipy.stats import chi2
 
 
-def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=20):
+def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=20, maxiter0=100, maxiter1=10):
     """
     run GWAS based on linear mixed model and put one snp in each analysis.
     :param pheno_file: phenotypic file. The fist column is individual id . The second column is always a column of 1s
@@ -19,6 +19,8 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=20):
     :param agmat_file: the prefix for the additive genomic relationship matrix file.
     :param out_file: the output file. Default is 'res.txt'.
     :param npart: divide the SNPs into n parts. Default is 20.
+    :param maxiter0: the maximum number of iteration for variance estimation in the null model
+    :param maxiter1: the maximum number of iteration for variance estimation in testing snp.
     :return:
     """
     logging.info("###Prepare the phenotypic values, covariates and genomic matrix")
@@ -29,7 +31,7 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=20):
     gmat_eigenvals = np.array(gmat_eigenvals).reshape(-1, 1)
     y_trans = np.dot(gmat_eigenvecs.T, y)  # transform the phenotypic values
     xmat_trans = np.dot(gmat_eigenvecs.T, xmat)  # transform the fixed effects
-    var, convergence = _weight_emai_eigen(y_trans, xmat_trans, gmat_eigenvals, init=init, maxiter=100, cc=1.0e-8)
+    var, convergence = _weight_emai_eigen(y_trans, xmat_trans, gmat_eigenvals, init=init, maxiter=maxiter0, cc=1.0e-8)
     logging.info('Whether converge?: {}'.format(convergence))
     logging.info('The estimated variances: {}'.format(var))
     snp_on_disk = Bed(bed_file, count_A1=False)
@@ -47,9 +49,10 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', npart=20):
     with open(out_file, 'w') as fout:
         fout.write('\t'.join(['chro', 'snp_ID', 'pos', 'allele1', 'allele2', 'cc', 'eff', 'se', 'p_wald']))
         fout.write('\n')
-    maxiter = 100
+    maxiter = maxiter1
     if not convergence:
         maxiter = 0
+
     for i in range(npart):
         logging.info('The {}/{} part'.format(i+1, npart))
         snp_info = pd.read_csv(bed_file + '.bim', sep='\s+', header=None, skiprows=snp_index[i],
