@@ -6,7 +6,7 @@ import time
 from scipy.stats import chi2
 from tqdm import tqdm
 
-from gmat.process_plink.process_plink import read_plink, impute_geno
+from gmat.process_plink.process_plink import impute_geno
 
 
 def uvlmm_gwas_add(y, xmat, gmat_lst, var_com, bed_file):
